summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgameproperty.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/kgameproperty.h')
-rw-r--r--libkdegames/kgame/kgameproperty.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/libkdegames/kgame/kgameproperty.h b/libkdegames/kgame/kgameproperty.h
index c5f35997..f02c4db0 100644
--- a/libkdegames/kgame/kgameproperty.h
+++ b/libkdegames/kgame/kgameproperty.h
@@ -125,8 +125,8 @@ public:
**/
KGamePropertyBase(int id, KGamePropertyHandler* owner);
- KGamePropertyBase(int id, KGame* tqparent);
- KGamePropertyBase(int id, KPlayer* tqparent);
+ KGamePropertyBase(int id, KGame* parent);
+ KGamePropertyBase(int id, KPlayer* parent);
/**
* Creates a KGamePropertyBase object without an owner. Remember to call
@@ -344,7 +344,7 @@ protected:
bool sendProperty(const TQByteArray& b);
/**
* Causes the tqparent object to emit a signal on value change
**/
void emitSignal();
@@ -413,7 +413,7 @@ private:
* property. This is achieved by using send to change the value of the
* property. send needs a running KMessageServer and therefore
* <em>MUST</em> be plugged into a KGamePropertyHandler using either
* registerData or the constructor. The tqparent of the dataHandler must be able
* to send messages (see above: the message server must be running). If you use
* send to change the value of a property you won't see the effect
* immediately: The new value is first transferred to the message server which
@@ -588,12 +588,12 @@ public:
* @param id The id of this property. <em>MUST be UNITQUE</em>! Used to send and
* receive changes in the property of the playere automatically via
* network.
* @param owner The tqparent of the object. Must be a KGame which manages
* the changes made to this object, i.e. which will send the new data.
* Note that in contrast to most KDE/QT classes KGameProperty objects
* are <em>not</em> deleted automatically!
**/
// TODO: ID: Very ugly - better use something like tqparent()->propertyId() or so which assigns a free id automatically.
KGameProperty(int id, KGamePropertyHandler* owner) : KGamePropertyBase(id, owner) { init(); }
/**
@@ -651,7 +651,7 @@ public:
* \endcode
* as myProperty has not yet been set when doSomething is being called.
*
* You are informed about a value change by a singal from the tqparent of
* the property which can be deactivated by setEmittingSignal because of
* performance (you probably don't have to deactivate it - except you
* want to write a real-time game like Command&Conquer with a lot of
@@ -344,7 +344,7 @@ protected:
bool sendProperty(const TQByteArray& b);
/**
- * Causes the tqparent object to emit a signal on value change
+ * Causes the parent object to emit a signal on value change
**/
void emitSignal();
@@ -413,7 +413,7 @@ private:
* property. send needs a running KMessageServer and therefore
* <em>MUST</em> be plugged into a KGamePropertyHandler using either
- * registerData or the constructor. The tqparent of the dataHandler must be able
+ * registerData or the constructor. The parent of the dataHandler must be able
* to send messages (see above: the message server must be running). If you use
* send to change the value of a property you won't see the effect
@@ -588,12 +588,12 @@ public:
* receive changes in the property of the playere automatically via
* network.
- * @param owner The tqparent of the object. Must be a KGame which manages
+ * @param owner The parent of the object. Must be a KGame which manages
* the changes made to this object, i.e. which will send the new data.
* Note that in contrast to most KDE/QT classes KGameProperty objects
@@ -588,12 +588,12 @@ public:
* are <em>not</em> deleted automatically!
**/
-// TODO: ID: Very ugly - better use something like tqparent()->propertyId() or so which assigns a free id automatically.
+// TODO: ID: Very ugly - better use something like parent()->propertyId() or so which assigns a free id automatically.
KGameProperty(int id, KGamePropertyHandler* owner) : KGamePropertyBase(id, owner) { init(); }
/**
@@ -651,7 +651,7 @@ public:
* as myProperty has not yet been set when doSomething is being called.
*
- * You are informed about a value change by a singal from the tqparent of
+ * You are informed about a value change by a singal from the parent of
* the property which can be deactivated by setEmittingSignal because of
* performance (you probably don't have to deactivate it - except you